@@ -85,8 +85,6 @@ static volatile bool lazyCCInit =
     true; // the flag must be 'volatile' to prevent caching in a CPU register
 static llvm::sys::Mutex lazyCCInitMutex;
 
-llvm::ManagedStatic<llvm::sys::SmartMutex<true>> compileMutex;
-
 void CommonClangTerminate() { llvm::llvm_shutdown(); }
 
 // This function mustn't be invoked from a static object constructor,
@@ -212,9 +210,6 @@ Compile(const char *pszProgramSource, const char **pInputHeaders,
   CommonClangInitialize();
 
   try {
-#ifdef _WIN32
-    llvm::sys::SmartScopedLock<true> compileGuard{*compileMutex};
-#endif
     std::unique_ptr<OCLFEBinaryResult> pResult(new OCLFEBinaryResult());
 
     // Create the clang compiler
@@ -226,9 +221,6 @@ Compile(const char *pszProgramSource, const char **pInputHeaders,
     // Prepare error log
     llvm::raw_string_ostream err_ostream(pResult->getLogRef());
     {
-#ifndef _WIN32
-      llvm::sys::SmartScopedLock<true> compileGuard{*compileMutex};
-#endif
       // Parse options
       optionsParser.processOptions(pszOptions, pszOptionsEx);
 
@@ -347,9 +339,6 @@ Compile(const char *pszProgramSource, const char **pInputHeaders,
       err_ostream.flush();
     }
     {
-#ifndef _WIN32
-      llvm::sys::SmartScopedLock<true> compileGuard{*compileMutex};
-#endif
       if (pBinaryResult) {
         *pBinaryResult = pResult.release();
       }
